# Image2ShortStroy
This is a Python package for easy Create Short Story from image captions using blip models by getting image captions.
 to get some information for any artworks, portraits, any images, and convert image captions to short stories using GPT-3 models
 
## Installation

```
pip install Image2Story==0.0.6

or in colab google cloud
!pip install Image2Story==0.0.6


```

## Tutorial
[Colab Google Drive](https://colab.research.google.com/drive/1ZR0cfKkOHvFi7E4IchLdc2S3JP83kvEp?usp=sharing)
```
u can see tutorial in colab google drive

```
